/* GStreamer
 * Copyright (C) 2017 Matthew Waters <matthew@centricular.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef __GST_WEBRTC_WEBRTC_H__
#define __GST_WEBRTC_WEBRTC_H__

#include <gst/gst.h>
#include <gst/webrtc/webrtc_fwd.h>
#include <gst/webrtc/webrtc-enumtypes.h>
#include <gst/webrtc/dtlstransport.h>
#include <gst/webrtc/ice.h>
#include <gst/webrtc/icestream.h>
#include <gst/webrtc/icetransport.h>
#include <gst/webrtc/rtcsessiondescription.h>
#include <gst/webrtc/rtpreceiver.h>
#include <gst/webrtc/rtpsender.h>
#include <gst/webrtc/rtptransceiver.h>
#include <gst/webrtc/datachannel.h>

#endif /* __GST_WEBRTC_WEBRTC_H__ */
